﻿using System;
using System.Linq;
using System.IO;

namespace Hegylancok
{
    class Hegylanc
    {
        //Privát adattagok:
        private bool[] sárga = new bool[80];
        private byte[] t;
        private int maxHossz;
        private double atlMagassag;

        //Publikus jellemzők
        public int MaxHossz { get { return maxHossz; } }
        public double AtlMagassag { get { return atlMagassag; } }

        public int HegyekSzáma
        {
            get
            {
                int hegyekSzáma = 0;
                for (int i = 1; i < t.Length - 1; i++)
                {
                    if (t[i] != 0 && //Ha az i-edik elem nem nulla
                        t[i - 1] == 0 && // Balra tőle nulla van
                        t[i + 1] == 0) // Jobbra tőle nulla van
                    { //akkor hegyről beszélünk:
                        hegyekSzáma++;
                        sárga[i] = true;
                    }
                }
                return hegyekSzáma;
            }
        }

        //Konstruktor:
        public Hegylanc(Random rnd)
        {
            t = new byte[80];
            for (int i = 3; i < t.Length - 3; i++) t[i] = (byte)rnd.Next(1, 16);
            for (int i = 3; i < t.Length - 3; i++) if (t[i] % 2 == 0) t[i] = 0;
            Szamol();
        }


        //Privát és publikus metódusok:
        private void Szamol() //Segéd privát metódus a 6. feladathoz
        {
            maxHossz = 0;
            int maxSzumMagasság = 0;
            int aktHossz = 0;
            int aktSzumMagasság = 0;
            for (int i = 0; i < t.Length; i++)
            {
                if (t[i] == 0) //Ha véget ér az aktuális hegylánc (vagy még el sem kezdődött): 
                {
                    if (aktHossz > 1 && aktHossz > maxHossz) //Hosszabb mint az előző?
                    {
                        maxHossz = aktHossz;
                        maxSzumMagasság = aktSzumMagasság;
                    }
                    aktHossz = 0;
                    aktSzumMagasság = 0;
                }
                else //Hegyláncban vagyunk:
                {
                    aktHossz++;
                    aktSzumMagasság += t[i]; //a maximális hosszhoz tartozó magasságösszegek megálapítására
                }
            }
            atlMagassag = (double)maxSzumMagasság / maxHossz;
        }
        public void Kiír(int fsz)
        {
            for (int i = 0; i < t.Length; i++)
            {
                if (fsz == 6 && sárga[i]) Console.BackgroundColor = ConsoleColor.Yellow;
                Console.Write("{0:X}", t[i]);
                Console.BackgroundColor = ConsoleColor.White;
            }
            Console.WriteLine();
        }

        public void Kiír(string fájlnév)
        {
            string stmp = "";
            foreach (var i in t) stmp += String.Format("{0:X}", i);
            File.WriteAllText(fájlnév, stmp);
            //vagy:
            //File.WriteAllText(fájlnév, t.Aggregate("",(c,n)=>c+String.Format("{0:X}",n)));
        }
    }

    class Hegylancok
    {

        static void Main()
        {
            Random r = new Random();

            //3. feladat:
            Hegylanc hl = new Hegylanc(r);

            //4. feladat:
            Console.WriteLine("4. feladat:");
            hl.Kiír(4);

            //5. feladat:
            Console.WriteLine("5. feladat: Hegyek száma: {0} db\n", hl.HegyekSzáma);

            //6. feladat:
            Console.WriteLine("6. feladat:");
            hl.Kiír(6);

            //7. feladat:
            if (hl.MaxHossz == 0) Console.WriteLine("Nincs hegylánc a vektorban!");
            else Console.WriteLine("7. feladat: Leghosszabb hegylánc hossza: {0} Átlagos magassága: {1:F1}", hl.MaxHossz, hl.AtlMagassag); //19. pont

            //8. feladat:
            hl.Kiír("hegylancok.txt");

            Console.ReadKey();

        }
    }
}
